LoginController class
Constructors
-
LoginController({Map<
String, String> ? initialValues}) - LoginController.fromJson(String json)
-
Initialize from JSON string
factory
-
LoginController.fromMap(Map<
String, dynamic> map) -
Create controller from Map
factory
Properties
- age → TextEditingController
-
final
- email → TextEditingController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → TextEditingController
-
final
- password → TextEditingController
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
anyEmpty(
) → bool - Check if any field is empty
-
clearAll(
) → void - Clear all fields
-
contains(
String value) → bool - Check if any field contains the given value
-
disposeAll(
) → void - Dispose all controllers
-
isEmpty(
) → bool - Check if all fields are empty
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValues(
Map< String, dynamic> values) → void - Set multiple fields at once
-
toJson(
) → String - Convert to JSON string
-
toMap(
) → Map< String, dynamic> - Convert all controller values to Map with type conversion
-
toString(
) → String -
A string representation of this object.
inherited
-
updateField(
String fieldName, String value) → void - Update single field safely
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited